==> numkeyboard-0.0.1.tar.gz: lib/keyboards/keyboard_binary_messenger.dart <==
part of numkeyboard;

class KeyboardBinaryMessenger extends BinaryMessenger {
  KeyboardBinaryMessenger(this.delegate) : assert(delegate != null);

  final BinaryMessenger delegate;

  final Map<String, MessageHandler> _inboundHandlers =
      <String, MessageHandler>{};

  @override
  Future<void> handlePlatformMessage(
      String channel, ByteData data, PlatformMessageResponseCallback callback) {
    Future<ByteData> result;
    if (_inboundHandlers.containsKey(channel)) {
      result = _inboundHandlers[channel](data);
    }
    result = Future<ByteData>.value(null);
    if (callback != null) {
      result = result.then((ByteData result) {
        callback(result);
        return result;
      });
    }
    return result;
  }

  final List<Future<ByteData>> _pendingMessages = <Future<ByteData>>[];

  int get pendingMessageCount => _pendingMessages.length;
  final Map<String, MessageHandler> _outboundHandlers =
      <String, MessageHandler>{};
  final Map<String, Object> _outboundHandlerIdentities = <String, Object>{};

  @override
  Future<ByteData> send(String channel, ByteData message) {
    final MessageHandler handler = _outboundHandlers[channel];
    Future<ByteData> result =
        handler == null ? delegate.send(channel, message) : handler(message);
    if (result != null) {
      _pendingMessages.add(result);
      result.catchError((Object error) {
        /* errors are the responsibility of the caller */
      }).whenComplete(() => _pendingMessages.remove(result));
    }
    return result;
  }

  @override
  void setMessageHandler(String channel, MessageHandler handler) {
    if (handler == null) {
      _inboundHandlers.remove(channel);
      delegate.setMessageHandler(channel, null);
    } else {
      _inboundHandlers[channel] = handler;
      delegate.setMessageHandler(channel, handler);
    }
  }

  Future<void> get platformMessagesFinished {
    return Future.wait<void>(_pendingMessages);
  }

  @override
  void setMockMessageHandler(String channel, MessageHandler handler,
      [Object identity]) {
    if (handler == null) {
      _outboundHandlers.remove(channel);
      _outboundHandlerIdentities.remove(channel);
    } else {
      identity = handler;
      _outboundHandlers[channel] = handler;
      _outboundHandlerIdentities[channel] = identity;
    }
  }

  void setMockDecodedMessageHandler<T>(
      BasicMessageChannel<T> channel, Future<T> Function(T message) handler) {
    if (handler == null) {
      setMockMessageHandler(channel.name, null);
      return;
    }
    setMockMessageHandler(channel.name, (ByteData message) async {
      return channel.codec
          .encodeMessage(await handler(channel.codec.decodeMessage(message)));
    }, handler);
  }

  void setMockMethodCallHandler(MethodChannel channel,
      Future<Object> Function(MethodCall message) handler) {
    if (handler == null) {
      setMockMessageHandler(channel.name, null);
      return;
    }
    setMockMessageHandler(channel.name, (ByteData message) async {
      final MethodCall call = channel.codec.decodeMethodCall(message);
      try {
        return channel.codec.encodeSuccessEnvelope(await handler(call));
      } on PlatformException catch (error) {
        return channel.codec.encodeErrorEnvelope(
          code: error.code,
          message: error.message,
          details: error.details,
        );
      } on MissingPluginException {
        return null;
      } catch (error) {
        return channel.codec.encodeErrorEnvelope(
            code: 'error', message: '$error', details: null);
      }
    }, handler);
  }

  @override
  bool checkMockMessageHandler(String channel, Object handler) =>
      _outboundHandlerIdentities[channel] == handler;

  @override
  bool checkMessageHandler(String channel, MessageHandler handler) {
    return false;
  }
}

==> numkeyboard-0.0.4.tar.gz: lib/keyboards/keyboard_binary_messenger.dart <==
part of numkeyboard;

class KeyboardBinaryMessenger extends BinaryMessenger {
  KeyboardBinaryMessenger(this.delegate) : assert(delegate != null);

  final BinaryMessenger delegate;

  final Map<String, MessageHandler> _inboundHandlers =
      <String, MessageHandler>{};

  @override
  Future<ByteData?> handlePlatformMessage(
      String channel, ByteData? data, PlatformMessageResponseCallback? callback) {
    Future<ByteData?>? result;
    if (_inboundHandlers.containsKey(channel)) {
      result = _inboundHandlers[channel]!(data);
    }
    result ??= Future<ByteData?>.value(null);
    if (callback != null) {
      result = result.then((ByteData? result) {
        callback(result);
        return result;
      });
    }
    return result;
  }

  final List<Future<ByteData?>> _pendingMessages = <Future<ByteData?>>[];

  int get pendingMessageCount => _pendingMessages.length;
  final Map<String, MessageHandler> _outboundHandlers =
      <String, MessageHandler>{};
  final Map<String, Object> _outboundHandlerIdentities = <String, Object>{};

  @override
  Future<ByteData?>? send(String channel, ByteData? message) {
    final MessageHandler? handler = _outboundHandlers[channel];
    Future<ByteData?>? result =
        handler == null ? delegate.send(channel, message) : handler(message);
    if (result != null) {
      _pendingMessages.add(result);
      result.catchError((Object error) {
        /* errors are the responsibility of the caller */
      }).whenComplete(() => _pendingMessages.remove(result));
    }
    return result;
  }

  @override
  void setMessageHandler(String channel, MessageHandler? handler) {
    if (handler == null) {
      _inboundHandlers.remove(channel);
      delegate.setMessageHandler(channel, null);
    } else {
      _inboundHandlers[channel] = handler;
      delegate.setMessageHandler(channel, handler);
    }
  }

  Future<void> get platformMessagesFinished {
    return Future.wait<void>(_pendingMessages);
  }

  @override
  void setMockMessageHandler(String channel, MessageHandler? handler,
      [Object? identity]) {
    if (handler == null) {
      _outboundHandlers.remove(channel);
      _outboundHandlerIdentities.remove(channel);
    } else {
      identity ??= handler;
      _outboundHandlers[channel] = handler;
      _outboundHandlerIdentities[channel] = identity;
    }
  }

  void setMockDecodedMessageHandler<T>(
      BasicMessageChannel<T> channel, Future<T> Function(T? message) handler) {
    if (handler == null) {
      setMockMessageHandler(channel.name, null);
      return;
    }
    setMockMessageHandler(channel.name, (ByteData? message) async {
      return channel.codec
          .encodeMessage(await handler(channel.codec.decodeMessage(message)));
    }, handler);
  }

  void setMockMethodCallHandler(MethodChannel channel,
      Future<Object?>? Function(MethodCall message) handler) {
    if (handler == null) {
      setMockMessageHandler(channel.name, null);
      return;
    }
    setMockMessageHandler(channel.name, (ByteData? message) async {
      final MethodCall call = channel.codec.decodeMethodCall(message);
      try {
        return channel.codec.encodeSuccessEnvelope(await handler(call));
      } on PlatformException catch (error) {
        return channel.codec.encodeErrorEnvelope(
          code: error.code,
          message: error.message,
          details: error.details,
        );
      } on MissingPluginException {
        return null;
      } catch (error) {
        return channel.codec.encodeErrorEnvelope(
            code: 'error', message: '$error', details: null);
      }
    }, handler);
  }

  @override
  bool checkMockMessageHandler(String channel, Object? handler) =>
      _outboundHandlerIdentities[channel] == handler;

  @override
  bool checkMessageHandler(String channel, MessageHandler? handler) {
    return false;
  }
}
